from setuptools import setup, find_packages

import os


def semantic() -> str:
    """
    Returns a semantic versioning without prefix
    that Github actions creates.

    :return: str
    """
    tag = '0.0.1'
    if os.environ.get('GITHUB_REF_TYPE') == 'tag':
        tag = os.environ.get('GITHUB_REF')
        if tag is not None:
            tag = tag[11:]

    return tag


def package_files(directory):
    """
    Generate a list of files to include in the package.

    :param directory:
    :return: list
    """
    paths = []
    for (path, directories, filenames) in os.walk(directory):
        for filename in filenames:
            paths.append(os.path.join('..', path, filename))
    return paths


extra_files = package_files('vanirio')
setup(
    name='vanirio',
    version=semantic(),
    description='Vanirio SDK package for easy development and production ready code.',
    author='Arjan de Meijer',
    author_email='arjan.demeijer@boschrexroth.nl',
    install_requires=['requests==2.26.0', 'pandas==1.3.4', 'chevron==0.14.0'],
    packages=find_packages(include=['vanirio']),
    package_data={
        'vanirio': extra_files
    },
    entry_points={
        'console_scripts': ['vanirio=vanirio.engine.cli:main']
    }
)