from abc import ABCMeta, abstractmethod
import pandas as pd


class RuntimeInterface(metaclass=ABCMeta):
    @abstractmethod
    def execute(self, dataset: pd.DataFrame, parameters: dict) -> pd.DataFrame:
        """
        Inside the execute code block all the logic needs to be formulated
        that generates a KPI or modifies the incoming dataset. See also
        the commissioning template for in-, output and parameter binding.
        (see documentation for help)

        :param dataset: Dataset with content as time-series.
        :param parameters: Dictionary with attached parameters.
        :return:
        """

        pass
