from abc import ABCMeta, abstractmethod

import pandas as pd


class TestInterface(metaclass=ABCMeta):
    @staticmethod
    @abstractmethod
    def input() -> pd.DataFrame:
        """
        Define a known dataset that is pushed inside your
        module software during test.

        :return: pd.DataFrame
        """
        pass

    @staticmethod
    @abstractmethod
    def parameters() -> dict:
        """
        Define a parameter dictionary that is pushed inside
        your module software during test.

        :return: dict.
        """
        pass

    @staticmethod
    @abstractmethod
    def output() -> pd.DataFrame:
        """
        Define a known dataset that must be equal to
        the dataset that your module software is
        creating during test (assert).

        :return: pd.DataFrame
        """
        pass
