from vanirio.engine.module import ModuleEngine
from pathlib import Path
from shutil import copyfile

import argparse
import os, sys

import uuid
import chevron


def engine_module(name: str, test: bool = False, example: bool = False):
    """
    Create or test the module.

    :param name:
    :param test:
    :param example:
    :return:
    """
    if not isinstance(name, str):
        raise ValueError("Module name should be of type str.")

    # path of user with name of module.
    _path = f'{os.getcwd()}/{name.lower()}'

    # create directory if not already exist.
    Path(_path).mkdir(exist_ok=True)

    # copy the template to the destination directory.
    pkgdir = sys.modules['vanirio'].__path__[0]

    _runtime = f'{pkgdir}/pipeline/templates/commissioning.mu'
    with open(_runtime, 'r') as f:
        content = chevron.render(f, {'tag': 'VANEENVARIABLE'})

        _com = f'{_path}/commissioning.py'
        with open(_com, 'w') as fw:
            fw.write(content)

    copyfile(f'{pkgdir}/pipeline/templates/__init__.py', f'{_path}/__init__.py')
    copyfile(f'{pkgdir}/pipeline/templates/runtime.py', f'{_path}/runtime.py')
    # copyfile(f'{pkgdir}/pipeline/templates/commissioning.py', f'{_path}/commissioning.py')
    copyfile(f'{pkgdir}/pipeline/templates/testing.py', f'{_path}/testing.py')


def engine_device(name: str, test: bool = False):
    """
    Create or test a device script.

    :param name:
    :param test:
    :return:
    """
    pass


def main():
    """
    The engine helps engineers to create and test new modules
    for the Vanirio backend pipeline. It also adds a feature
    to easily setup a Python script for upload device files
    to the Vanirio data lake via the API.

    :return:
    """
    try:
        parser = argparse.ArgumentParser(description='Vanirio Engine')
        parser.add_argument('cmd', nargs='?',
                            help='Vanirio command')

        parser.add_argument('name', nargs='?', default=f'v{uuid.uuid4()}',
                            help='Name')

        parser.add_argument('--test', dest='test', action='store_true',
                            help='Activate testing')

        parser.add_argument('--example', dest='example', action='store_true',
                            help='Attach example')

        parser.add_argument('--pck', dest='pck', action='store_true',
                            help='Package the module')

        args = parser.parse_args()

        # engine for module template.
        if args.cmd == 'module':
            mod = ModuleEngine(args.name)

            # run the test engine and return.
            if args.test:
                mod.test()
                return

            # return the package engine and return.
            if args.pck:
                mod.package()
                return

            # generate the module with or without example.
            mod.create(args.example)

    except BaseException as error:
        print(error)
        print("Unable to execute the Vanirio Engine")
