"""
Module: {{name}}
Created-At: {{timestamp}}
{{# example }}

The commissioning class is used to interface your module software to the
backend of Vanirio. It helps the operator of a particular dashboard or
an API to intuitive integrate your software module in the backend. Inputs
are used to inform the operator that a particular dataset  column in
the backend must be attached to a defined column in your dataset. Outputs
are used to inform the user that this module returns a dataset with x output
columns in the dataset. Each output represent a column in your dataset.
To broader the use-case for your module, it is helpful to integrate
parameters into your module such that reuse of the module is stimulated.
{{/ example }}

Command Line Interface:
$ vanirio module {{name}} --test
$ vanirio module {{name}} --pck
"""
from vanirio.pipeline.interface import Interface
from vanirio.abstract import CommissioningInterface
{{# example }}
from vanirio.pipeline.interface import Input, Output, Number
{{/ example }}


class Commissioning(CommissioningInterface):
    def object(self, container: Interface) -> Interface:
        """
        Inside this method you need to define all the interface
        objects that describe the input, output of the module.
        Use parameters to make the module configurable.

        :param container: interface container
        :return: interface container
        """
        {{# example }}

        # Inside a group method we can define inputs as shown below.
        # It is not required to put interface objects in separated groups,
        # however, it could happen that the GUI needs a clear separation
        # of the objects. The backend will ignore the grouping! With the
        # interface objects below, we tell the GUI and backend that this
        # module requires two columns inside the ingoing dataset named
        # 'rod' and 'bottom'.
        container.group(
            Input('Cylinder Rod Pressure', 'rod'),
            Input('Cylinder Bottom Pressure', 'bottom')
        )

        # With the interface objects below, we tell the GUI and backend that
        # this module creates an outgoing dataset with two columns named
        # 'max_rod' and 'max_bottom'.
        container.group(
            Output('Maximum Rod Pressure', 'max_rod'),
            Output('Maximum Bottom Pressure', 'max_bottom')
        )

        # The interface object below describes that the module contains
        # a configurable parameter. The type of the object is Number which
        # indicates that the user needs to assign a number (integer, float)
        # during the boarding process of this module inside the pipeline. The
        # field is required and has a placeholder text for additional help for
        # when using a GUI. The name of the parameter inside the module is
        # 'cil_length'.
        param = Number('Cylinder Length', 'cil_length')
        param.required = True
        param.placeholder = 'Define the length of the cylinder in mm\'s.'
        container.group(
          param
        )

        {{/ example }}
        return container
