"""
Module: {{name}}
Created-At: {{timestamp}}
{{# example }}

The runtime class is the software container for your module. Inside
the execute method below you need to define all the logic necessary for
transforming or calculating the returning outgoing dataset a.k.a KPI(s).
The incoming dataset is generated for you in the backend, so don't you
worry about that! The return value of the execute method must be a valid
DataFrame from the Pandas dependency and contain a indexed datetime column
named 'timestamp' with format %Y-%m-%d %H:%M:%S. The parameter dictionary
is also generated during runtime in the backend. You can define a test-case
inside 'testing.py' that acts as a backend during development stage.
{{/ example }}

Command Line Interface:
$ vanirio module {{name}} --test
$ vanirio module {{name}} --pck
"""
from vanirio.abstract import RuntimeInterface

import pandas as pd


class Runtime(RuntimeInterface):
    def execute(self, dataset: pd.DataFrame, parameters: dict) -> pd.DataFrame:
        """
        Inside this method you need to define the logic of your module.
        The ingoing dataset and parameters are generated for your in the
        backend. Make sure you return a DataFrame with a datetime indexed
        column 'timestamp' and the columns defined in 'commissioning.py'.

        :param dataset: pd.Dataframe containing dataset.
        :param parameters: dict containing parameters.
        :return: pd.Dataframe with outgoing dataset.
        """
        {{# example }}

        # It is possible to fail the execution of KPI's if
        # not all defined parameters are set or are set incorrect.
        # In that case, raise an exception with your error message.
        if 'cil_length' not in parameters:
            raise ValueError('cil_length not set during runtime')

        # We calculate the final KPI's based on the parameter
        # 'cil_length' and the maximum value of each column in
        # incoming dataset.
        calculation = dataset.max() * parameters['cil_length']

        # Finally we create a dataset with the predefined output columns
        # defined in 'commissioning.py'. In order to define the timestamp
        # of the KPI's, we use a runtime variable 'RUNTIME_TIME' which
        # indicates when the underlying pipeline runtime is started. It
        # is also possible to provide your own timestamp based on the
        # incoming dataset timestamps.
        return pd.DataFrame({
            'timestamp': pd.date_range(start=parameters['RUNTIME_TIME'], periods=1, freq='s'),
            'max_rod': calculation['rod'],
            'max_bottom': calculation['bottom']
        }).set_index('timestamp')
        {{/ example }}
        {{# not_example }}
        # todo: create an outgoing dataset according commissioning interface!
        return pd.DataFrame()
        {{/ not_example }}
