"""
Module: {{name}}
Created-At: {{timestamp}}
{{# example }}

The testing class is used to test the software defined in your
module. During the test the input() and parameters() methods
are called and the content is pushed inside your software. The
outcome of your software is challenged/asserted against the
known dataset stored inside the output() method in this file.
The avoid timestamp issues, the test ignores the timestamp
difference during test. The test results in a message which
is either an okay message or exception error message.
{{/ example }}

Command Line Interface:
$ vanirio module {{name}} --test
$ vanirio module {{name}} --pck
"""
from vanirio.abstract import TestInterface

import pandas as pd


class Testing(TestInterface):
    @staticmethod
    def input() -> pd.DataFrame:
        """
        Inside this method you can define your known dataset
        with an datetime indexed column 'timestamp' and the
        input columns defined in 'commissioning.py'. During
        testing, this dataset is pushed inside your module
        software defined in 'runtime.py'.

        :return: pd.DataFrame
        """
        {{# example }}

        # The ingoing dataset contains two columns as defined in
        # 'commissioning.py' and has three rows in total. Starting
        # from 2021-01-01 00:00:00 until 2021-01-01 00:00:02.
        return pd.DataFrame({
            'timestamp': pd.date_range(start='2021-01-01 00:00:00', periods=3, freq='s'),
            'rod': [*range(1, 4, 1)],  # [1, 2, 3]
            'bottom': [*range(2, 8, 2)]  # [2, 4, 6]
        }).set_index('timestamp')
        {{/ example }}
        {{# not_example }}
        # todo: create an ingoing dataset according commissioning interface!
        return pd.DataFrame()
        {{/ not_example }}

    @staticmethod
    def parameters() -> dict:
        """
        Inside this method you can define your known dictionary
        with parameters as defined in 'commissioning.py'. During
        testing, this dictionary is pushed inside your module
        software defined in 'runtime.py'. If not used, return
        an empty dictionary.

        :return: dict.
        """
        {{# example }}
        return {
            'cil_length': 1234
        }
        {{/ example }}
        {{# not_example }}
        # todo: create an parameter dict according commissioning interface!
        return {}
        {{/ not_example }}

    @staticmethod
    def output() -> pd.DataFrame:
        """
        Inside this method you can define your known dataset
        with an datetime indexed column 'timestamp' and the
        output columns defined in 'commissioning.py'. During
        testing, this dataset is challenged/asserted against
        the dataset that is generated by the 'runtime.py'
        software of your module.

        :return: pd.DataFrame
        """
        {{# example }}

        # The outgoing dataset contains two columns as defined
        # in 'commissioning.py'. The dataset contains a single
        # row where each row/column value is the product of the
        # maximum value of the input dataset column and the
        # 'cil_length' parameter. In the test we going to ignore
        # the timestamp, so the value is arbitrary chosen.
        return pd.DataFrame({
            'timestamp': pd.date_range(start='2021-05-05 12:15:45', periods=1, freq='s'),
            'max_rod': [3702],  # <= 3 * 1234
            'max_bottom': [7404]  # <= 6 * 1234
        }).set_index('timestamp')
        {{/ example }}
        {{# not_example }}
        # todo: create an outgoing dataset according commissioning interface!
        return pd.DataFrame()
        {{/ not_example }}
