from .number import Number
from .textfield import Textfield
from .input import Input
from .output import Output

class Interface:
    def __init__(self):
        """
        An interface object holds all the input, output and parameter
        interface objects belonging to the module software. Use the group()
        method to attach interface objects to the Interface object. To
        separate groups, reuse the group() method.
        """
        self._groups = []

    def group(self, *args, **kwargs):
        """
        A group holds an arbitrary number of interface objects. The
        group can be used to distinguish elements in the GUI, but
        does not have a function in the pipeline software.

        :param args: interface object(s)
        :param kwargs:
        :return:
        """
        subgroup = []
        if len(args) > 0:
            for o in args:
                if isinstance(o, Number):
                    subgroup.append(o)

                if isinstance(o, Textfield):
                    subgroup.append(o)

                if isinstance(o, Input):
                    subgroup.append(o)

                if isinstance(o, Output):
                    subgroup.append(o)

        self._groups.append(subgroup)

    def objects(self) -> list:
        """
        The objects method returns a list of grouped
        interface objects.

        :return: list
        """
        return self._groups
