class Base:
    def __init__(self):
        """
        Each interface object contains at least the properties
        described in this base class.

        """
        self._tag = None
        self._label = None
        self._placeholder = None
        self._type = None
        self._required = False

    @property
    def tag(self) -> str:
        """
        The tag property is used to bind the pipeline logic
        to the user defined input. A tag must be unique in the
        interface object.

        :return: str
        """
        return self._tag

    @tag.setter
    def tag(self, value):
        """
        The label property is used to display a human friendly
        label to indicate the functionality of the interface
        object in the GUI.

        :return:
        """
        if not isinstance(value, str):
            raise ValueError(f'tag of {self} field must be of type str')

        if len(value) not in range(2, 64, 1):
            raise ValueError(f'tag must have min 2, max 64 characters')

        self._tag = value

    @property
    def label(self) -> str:
        """
        The label property is used to display a human friendly
        label to indicate the functionality of the interface
        object in the GUI.

        :return: str
        """
        return self._label

    @label.setter
    def label(self, value: str):
        """
        The label property is used to display a human friendly
        label to indicate the functionality of the interface
        object in the GUI.

        :param value:
        :return:
        """
        if not isinstance(value, str):
            raise ValueError(f'label of {self} field must be of type str')

        if len(value) not in range(2, 64, 1):
            raise ValueError(f'label must have min 2, max 64 characters')

        self._label = value

    @property
    def placeholder(self) -> str:
        """
        The placeholder is used to display a human friendly
        text inside the GUI field to inform what kind of
        value is expected.

        :return: str
        """
        return self._label

    @placeholder.setter
    def placeholder(self, value: str):
        """
        The placeholder is used to display a human friendly
        text inside the GUI field to inform what kind of
        value is expected.

        :param value:
        :return:
        """
        if not isinstance(value, str):
            raise ValueError(f'placeholder of {self} field must be of type str')

        if len(value) not in range(2, 64, 1):
            raise ValueError(f'placeholder must have min 2, max 64 characters')

        self._placeholder = value

    @property
    def required(self) -> bool:
        """
        Property indicates if the field
        is required to for the interface.

        :return: bool
        """
        return self._label

    @required.setter
    def required(self, value: bool):
        """
        Property indicates if the field
        is required to for the interface.

        :param value:
        :return:
        """
        if not isinstance(value, bool):
            raise ValueError(f'required of {self} field must be of type bool')

        self._required = value
